========
MU Build
========

About
==============

Provided with config file, mu_build fetches/clones dependencies then compiles every module in each package.
This is the entrypoint into the CI / Pull Request build and test infrastructure.

Version History
===============

0.2.1
-----

Updating to new version of MU Environment

0.2.0
-----

Initial commit